from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKPointOfInterestCategory(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(MapKit.MKPointOfInterestCategory, str)

    @min_os_level("10.15")
    def test_constants(self):
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryAirport, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryAmusementPark, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryAquarium, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryATM, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBakery, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBank, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBeach, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBrewery, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryCafe, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryCampground, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryCarRental, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryEVCharger, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryFireStation, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryFitnessCenter, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryFoodMarket, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryGasStation, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryHospital, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryHotel, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryLaundry, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryLibrary, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryMarina, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryMovieTheater, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryMuseum, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryNationalPark, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryNightlife, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPark, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryParking, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPharmacy, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPolice, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPostOffice, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPublicTransport, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryRestaurant, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryRestroom, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategorySchool, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryStadium, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryStore, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryTheater, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryUniversity, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryWinery, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryZoo, str)
